LambdaTwist

Struct LambdaTwist 

#[non_exhaustive]
pub struct LambdaTwist { pub gauss_newton_iterations: usize, pub rotation_convergence_iterations: usize, pub rotation_convergence_epsilon: f64, }
The core P3P algorithm named Lambda Twist. Estimates up to 4 potential WorldToCamera poses.

Returns 0 to 4 potential solutions to the equation:

Formula

  • x_i are the 3D point world coordinates.
  • y_i are the image coordinates Formula (also sometimes called “bearing vectors”).
  • lambda_i are the signed distances from the camera.

This struct is marked as #[non_exhaustive] to allow the backwards-compatible addition of new fields.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
gauss_newton_iterations: usize

This determines the number of iterations that Gauss-Newton is ran on the poses to optimize them. The paper notes that it rarely improves after two iterations. The original implementation uses 5 iterations.

rotation_convergence_iterations: usize

This determines the number of iterations to spend converging on a proper rotation matrix.

rotation_convergence_epsilon: f64

The epsilon on which convergence is considered achieved for converging on a proper rotation.

Implementations

Source

impl LambdaTwist

pub fn new() -> Self

Creates a default lambda twist with 5 iterations of Gauss-Newton.

pub fn gauss_newton_iterations(self, gauss_newton_iterations: usize) -> Self

pub fn rotation_convergence_iterations( self, rotation_convergence_iterations: usize, ) -> Self

pub fn rotation_convergence_epsilon( self, rotation_convergence_epsilon: f64, ) -> Self